
# Class: EmbeddingsConfig


Embeddings configuration.

URI: [https://w3id.org/neat/EmbeddingsConfig](https://w3id.org/neat/EmbeddingsConfig)


[![img](https://yuml.me/diagram/nofunky;dir:TB/class/[NodeEmbeddingsParams],[NodeEmbeddingsParams]<node_embeddings_params%200..1-++[EmbeddingsConfig&#124;filename:string%20%3F;history_filename:string%20%3F;tsne_filename:string%20%3F])](https://yuml.me/diagram/nofunky;dir:TB/class/[NodeEmbeddingsParams],[NodeEmbeddingsParams]<node_embeddings_params%200..1-++[EmbeddingsConfig&#124;filename:string%20%3F;history_filename:string%20%3F;tsne_filename:string%20%3F])

## Attributes


### Own

 * [➞filename](embeddingsConfig__filename.md)  <sub>0..1</sub>
     * Description: Embeddings file name.
     * Range: [String](types/String.md)
 * [➞history_filename](embeddingsConfig__history_filename.md)  <sub>0..1</sub>
     * Description: Embeddings history file name.
     * Range: [String](types/String.md)
 * [➞node_embeddings_params](embeddingsConfig__node_embeddings_params.md)  <sub>0..1</sub>
     * Description: Node embeddings parameters.
     * Range: [NodeEmbeddingsParams](NodeEmbeddingsParams.md)
 * [➞tsne_filename](embeddingsConfig__tsne_filename.md)  <sub>0..1</sub>
     * Description: File name for the TSNE plot.
     * Range: [String](types/String.md)
